import { Hash } from "./hash.js";
import CRC32C from "./algorithms/crc32c.js";
import { encodeNumber } from "./utils/digest-utils.js";
export class CRC32CHash extends Hash {
  constructor() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    super();
    this.name = 'crc32c';
    this.options = void 0;
    this.options = {
      crypto: {},
      ...options
    };
  }
  async hash(input, encoding) {
    return this.hashSync(input, encoding);
  }
  hashSync(input, encoding) {
    const hash = new CRC32C(this.options);
    hash.update(input);
    const digest = hash.finalize();
    return encodeNumber(digest, encoding);
  }
  hashBatches(asyncIterator) {
    try {
      var _this = this;
      let encoding = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'base64';
      return async function* () {
        var _this$options$crypto, _this$options$crypto$;
        const hash = new CRC32C(_this.options);
        for await (const chunk of asyncIterator) {
          hash.update(chunk);
          yield chunk;
        }
        const digest = hash.finalize();
        (_this$options$crypto = _this.options.crypto) === null || _this$options$crypto === void 0 ? void 0 : (_this$options$crypto$ = _this$options$crypto.onEnd) === null || _this$options$crypto$ === void 0 ? void 0 : _this$options$crypto$.call(_this$options$crypto, {
          hash: encodeNumber(digest, encoding)
        });
      }();
    } catch (e) {
      return Promise.reject(e);
    }
  }
}
//# sourceMappingURL=crc32c-hash.js.map