import { Hash } from "./hash.js";
let CryptoJS;
export class CryptoHash extends Hash {
  constructor(options) {
    var _this$options, _this$options$crypto;
    super();
    this.name = void 0;
    this.options = void 0;
    this._algorithm = void 0;
    this._algo = void 0;
    this.options = options;
    this._algorithm = (_this$options = this.options) === null || _this$options === void 0 ? void 0 : (_this$options$crypto = _this$options.crypto) === null || _this$options$crypto === void 0 ? void 0 : _this$options$crypto.algorithm;
    if (!this._algorithm) {
      throw new Error(this.name);
    }
    this.name = this._algorithm.toLowerCase();
  }
  async preload() {
    if (!CryptoJS) {
      var _this$options2, _this$options2$module;
      CryptoJS = (_this$options2 = this.options) === null || _this$options2 === void 0 ? void 0 : (_this$options2$module = _this$options2.modules) === null || _this$options2$module === void 0 ? void 0 : _this$options2$module.CryptoJS;
    }
    if (!CryptoJS) {
      throw new Error(this.name);
    }
    this._algo = CryptoJS.algo[this._algorithm];
  }
  async hash(input, encoding) {
    await this.preload();
    const hash = this._algo.create();
    if (!hash) {
      throw new Error(this.name);
    }
    const typedWordArray = CryptoJS.lib.WordArray.create(input);
    const enc = encoding === 'base64' ? CryptoJS.enc.Base64 : CryptoJS.enc.Hex;
    return hash.update(typedWordArray).finalize().toString(enc);
  }
  hashBatches(asyncIterator) {
    try {
      var _this = this;
      let encoding = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'base64';
      return async function* () {
        var _this$options3, _this$options3$crypto, _this$options3$crypto2;
        await _this.preload();
        const hash = _this._algo.create();
        if (!hash) {
          throw new Error(_this.name);
        }
        for await (const chunk of asyncIterator) {
          const typedWordArray = CryptoJS.lib.WordArray.create(chunk);
          hash.update(typedWordArray);
          yield chunk;
        }
        const enc = encoding === 'base64' ? CryptoJS.enc.Base64 : CryptoJS.enc.Hex;
        const digest = hash.finalize().toString(enc);
        (_this$options3 = _this.options) === null || _this$options3 === void 0 ? void 0 : (_this$options3$crypto = _this$options3.crypto) === null || _this$options3$crypto === void 0 ? void 0 : (_this$options3$crypto2 = _this$options3$crypto.onEnd) === null || _this$options3$crypto2 === void 0 ? void 0 : _this$options3$crypto2.call(_this$options3$crypto, {
          hash: digest
        });
      }();
    } catch (e) {
      return Promise.reject(e);
    }
  }
}
//# sourceMappingURL=crypto-hash.js.map